==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGridPinningActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionsBaseDirectiveDescriptionMetadata } from "./WebGridActionsBaseDirectiveDescriptionMetadata";
import { WebGridPinningActionsDescription } from "./WebGridPinningActionsDescription";
/**
 * @hidden
 */
export let WebGridPinningActionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridPinningActionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridPinningActionsDescriptionMetadata.a == null) {
                WebGridPinningActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridPinningActionsDescriptionMetadata.c(WebGridPinningActionsDescriptionMetadata.a);
            }
            if (a.j(WebGridPinningActionsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridPinningActionsDescriptionMetadata.a);
        }
        static c(a) {
            WebGridActionsBaseDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridPinningActions");
            a.item("__tagNameWC", "String:igc-grid-pinning-actions");
            a.item("__packageNameWC", "String:grids");
        }
        static d(a) {
            WebGridPinningActionsDescriptionMetadata.b(a);
            a.aa("WebGridPinningActions", () => new WebGridPinningActionsDescription());
            a.z("WebGridPinningActions", WebGridPinningActionsDescriptionMetadata.a);
        }
    }
    WebGridPinningActionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridPinningActionsDescriptionMetadata, 'WebGridPinningActionsDescriptionMetadata');
    WebGridPinningActionsDescriptionMetadata.a = null;
    return WebGridPinningActionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridPinningActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionsBaseDirectiveDescriptionMetadata } from "./WebGridActionsBaseDirectiveDescriptionMetadata";
import { WebGridPinningActionsDescription } from "./WebGridPinningActionsDescription";
/**
 * @hidden
 */
export let WebGridPinningActionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridPinningActionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridPinningActionsDescriptionMetadata.a == null) {
                WebGridPinningActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridPinningActionsDescriptionMetadata.c(WebGridPinningActionsDescriptionMetadata.a);
            }
            if (a.k(WebGridPinningActionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridPinningActionsDescriptionMetadata.a);
        }
        static c(a) {
            WebGridActionsBaseDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridPinningActions");
            a.item("__tagNameWC", "String:igc-grid-pinning-actions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            if (a.containsKey("__skipSuffix")) {
                a.removeItem("__skipSuffix");
            }
        }
        static d(a) {
            WebGridPinningActionsDescriptionMetadata.b(a);
            a.ac("WebGridPinningActions", () => new WebGridPinningActionsDescription());
            a.ab("WebGridPinningActions", WebGridPinningActionsDescriptionMetadata.a);
        }
    }
    WebGridPinningActionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridPinningActionsDescriptionMetadata, 'WebGridPinningActionsDescriptionMetadata');
    WebGridPinningActionsDescriptionMetadata.a = null;
    return WebGridPinningActionsDescriptionMetadata;
})();
